==> twinlisp-0.3.2.tar.gz: twinlisp/core/interpreter.lisp <==
;
;Copyright (C) 2006 Mikalai Birukou
;
;This file is part of TwinLisp.
;
;    TwinLisp is free software; you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation; either version 2 of the License, or
;    (at your option) any later version.
;
;    TwinLisp is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with TwinLisp; if not, write to the Free Software
;    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
(_<<_ (_<<_ (_<<_ (_<<_ (cout) "TwinLisp interpreter.") #\Newline) "Typing \"Ctrl-D\" or \"exit\" quits interpreter.") #\Newline)
(var *tl-level-info* (TWINLISP::makeLevelInfo :implScope cl:t :explScopeWarn cl:t))
; &*print-circle* = t  ; so that our printer does not choke on circles
(cl:catch :exit (cl:do (+ ++ +++ - * ** ***) (cl:nil) (cl:handler-case (cl:progn (cl:setf - (read-from-string (translate *tl-level-info*))) (cl:setf *** (multiple-value-list (eval -))) (_<<_ (cout) #\Newline) (write (car ***)) (cl:cond ((_>_ (len ***) 1) (tl-for (value (cdr ***)) (cl:nil) (_<<_ (_<<_ (cout) "  ;") #\Newline) (write value)))) (_<<_ (cout) #\Newline)) (error (er) (_<<_ (cout) (_%_ "ERROR: ~A~%" er)) (cl:setf *** (cl:list er)))) (cl:setf +++ (car ***)) (cl:setf *** **) (cl:setf ** *) (cl:setf * +++) (cl:setf +++ ++) (cl:setf ++ +) (cl:setf + -)))

==> twinlisp-0.5.tar.gz: twinlisp/core/interpreter.lisp <==
;
;Copyright (C) 2006 Mikalai Birukou
;
;This file is part of TwinLisp.
;
;    TwinLisp is free software; you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation; either version 2 of the License, or
;    (at your option) any later version.
;
;    TwinLisp is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with TwinLisp; if not, write to the Free Software
;    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
(_<<_ (_<<_ (_<<_ (_<<_ (cout) "TwinLisp interpreter.") #\Newline) "Typing \"Ctrl-D\" or \"exit\" quits interpreter.") #\Newline)
(var *tl-level-info* (TWINLISP::makeLevelInfo :implScope cl:t :explScopeWarn cl:t))
; &*print-circle* = t  ; so that our printer does not choke on circles
(cl:catch :exit (cl:do (+ ++ +++ - * ** ***) (cl:nil) (cl:handler-case (cl:progn (cl:setf - (read-from-string (translate *tl-level-info* (new TWINLISP::ReaderWriter :firstPrompt ">>> " :secondPrompt "... ") cl:t "exit"))) (cl:setf *** (multiple-value-list (eval -))) (_<<_ (cout) #\Newline) (write (car ***)) (cl:cond ((_>_ (len ***) 1) (tl-for (value (cdr ***)) (cl:nil) (_<<_ (_<<_ (cout) "  ;") #\Newline) (write value)))) (_<<_ (cout) #\Newline)) (error (er) (_<<_ (cout) (_%_ "ERROR: ~A~%" er)) (cl:setf *** (cl:list er)))) (cl:setf +++ (car ***)) (cl:setf *** **) (cl:setf ** *) (cl:setf * +++) (cl:setf +++ ++) (cl:setf ++ +) (cl:setf + -)))
